@@ -127,7 +127,7 @@ class CoverGrid(Browser, util.InstanceTracker, VisibleUpdate,
     name = _("Cover Grid")
     accelerated_name = _("_Cover Grid")
     keys = ["CoverGrid"]
-    priority = 4
+    priority = 5
 
     def pack(self, songpane):
         container = self.songcontainer
@@ -354,6 +354,9 @@ class CoverGrid(Browser, util.InstanceTracker, VisibleUpdate,
                 window = Information(librarian, songs, self)
                 window.show()
             return True
+        elif qltk.is_accel(event, "<Primary>Return", "<Primary>KP_Enter"):
+            qltk.enqueue(self.__get_selected_songs(sort=True))
+            return True
         elif qltk.is_accel(event, "<alt>Return"):
             songs = self.__get_selected_songs()
             if songs:
@@ -438,7 +441,7 @@ class CoverGrid(Browser, util.InstanceTracker, VisibleUpdate,
         album = model.get_album(iter_)
         if album is None:
             return config.getboolean("browsers", "covergrid_all", False)
-        key = util.gdecode(key).lower()
+        key = key.lower()
         title = album.title.lower()
         if key in title:
             return False
