@@ -19,7 +19,6 @@ from quodlibet.browsers import Browser
 from quodlibet.browsers._base import DisplayPatternMixin
 from quodlibet.browsers.playlists.prefs import Preferences, \
     DEFAULT_PATTERN_TEXT
-from quodlibet.compat import listfilter
 from quodlibet.formats import AudioFile
 from quodlibet.plugins.playlist import PLAYLIST_HANDLER
 from quodlibet.qltk.completion import LibraryTagCompletion
@@ -394,7 +393,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
         model = view.get_model()
         if tid == DND_QL:
             filenames = qltk.selection_get_filenames(sel)
-            songs = listfilter(None, [library.get(f) for f in filenames])
+            songs = list(filter(None, [library.get(f) for f in filenames]))
             if not songs:
                 Gtk.drag_finish(ctx, False, False, etime)
                 return
@@ -430,7 +429,8 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
                 sock = urlopen(uri)
                 if uri.lower().endswith('.pls'):
                     playlist = parse_pls(sock, name, library=library)
-                elif uri.lower().endswith('.m3u'):
+                elif (uri.lower().endswith('.m3u') or
+                        uri.lower().endswith('.m3u8')):
                     playlist = parse_m3u(sock, name, library=library)
                 else:
                     raise IOError
@@ -442,7 +442,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
                 qltk.ErrorMessage(
                     qltk.get_top_parent(self),
                     _("Unable to import playlist"),
-                    _("Quod Libet can only import playlists in the M3U "
+                    _("Quod Libet can only import playlists in the M3U/M3U8 "
                       "and PLS formats.")).run()
 
     def _drag_data_get(self, view, ctx, sel, tid, etime):
@@ -600,7 +600,8 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
             self._select_playlist(playlist, scroll=True)
 
     def __import(self, activator, library):
-        cf = create_chooser_filter(_("Playlists"), ["*.pls", "*.m3u"])
+        formats = ["*.pls", "*.m3u", "*.m3u8"]
+        cf = create_chooser_filter(_("Playlists"), formats)
         fns = choose_files(self, _("Import Playlist"), _("_Import"), cf)
         self._import_playlists(fns, library)
 
@@ -609,7 +610,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
         for filename in fns:
             name = _name_for(filename)
             with open(filename, "rb") as f:
-                if filename.endswith(".m3u"):
+                if filename.endswith(".m3u") or filename.endswith(".m3u8"):
                     playlist = parse_m3u(f, name, library=library)
                 elif filename.endswith(".pls"):
                     playlist = parse_pls(f, name, library=library)
