@@ -15,7 +15,6 @@ from quodlibet.qltk.entry import UndoEntry
 from quodlibet.qltk import Icons
 from quodlibet.util.string import decode
 from quodlibet.plugins.events import EventPlugin
-from quodlibet.compat import text_type
 
 
 def _config(section, option, label, tooltip=None, getter=None):
@@ -51,7 +50,7 @@ def text_config(section, option, label, tooltip=None):
 def boolean_config(section, option, label, tooltip):
 
     def getter(section, option):
-        return text_type(config.getboolean(section, option))
+        return str(config.getboolean(section, option))
 
     return _config(section, option, label, tooltip, getter)
 
@@ -59,7 +58,7 @@ def boolean_config(section, option, label, tooltip):
 def int_config(section, option, label, tooltip):
 
     def getter(section, option):
-        return text_type(config.getint(section, option))
+        return str(config.getint(section, option))
 
     return _config(section, option, label, tooltip, getter)
 
