@@ -10,6 +10,8 @@
 
 import threading
 from xml.dom import minidom
+from urllib.parse import quote
+import queue
 
 from quodlibet import _, print_d
 from quodlibet.plugins.gui import UserInterfacePlugin
@@ -32,7 +34,6 @@ from quodlibet.util import escape, cached_property, connect_obj
 from quodlibet.qltk import Icons, Align
 from quodlibet.qltk.entry import UndoEntry
 from quodlibet.pattern import URLFromPattern
-from quodlibet.compat import quote, queue
 from quodlibet.util.urllib import urlopen
 
 
