@@ -24,6 +24,8 @@ class DSFFile(ID3File):
         self["~#length"] = info.length
         self["~#bitrate"] = int(info.bitrate / 1000)
         self["~#channels"] = info.channels
+        self["~#samplerate"] = info.sample_rate
+        self["~#bitdepth"] = info.bits_per_sample
 
 loader = DSFFile
 types = [DSFFile]
