@@ -2,13 +2,11 @@
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
-import os
-
-from quodlibet.util.path import fsnative, is_fsnative
-from quodlibet.compat import text_type
+from senf import fsnative, path2fsn
 
 from ._audio import AudioFile
 
@@ -23,17 +21,16 @@ class RemoteFile(AudioFile):
     format = "Remote File"
 
     def __init__(self, uri):
-        self["~uri"] = text_type(uri)
+        assert not isinstance(uri, bytes)
+        self["~uri"] = str(uri)
         self.sanitize(fsnative(self["~uri"]))
 
     def __getitem__(self, key):
         # we used to save them with the wrong type
         value = super(RemoteFile, self).__getitem__(key)
-        if key in ("~filename", "~mountpoint") and not is_fsnative(value):
-            if os.name == "nt":
-                value = unicode(value)
-            else:
-                value = value.encode("utf-8")
+        if key in ("~filename", "~mountpoint") and \
+                not isinstance(value, fsnative):
+            value = path2fsn(value)
 
         return value
 
