@@ -13,7 +13,6 @@ from quodlibet.util.modulescanner import ModuleScanner
 from quodlibet.util.dprint import print_d
 from quodlibet.util.config import ConfigProxy
 from quodlibet.qltk.ccb import ConfigCheckButton
-from quodlibet.compat import itervalues, iteritems, listkeys, string_types
 
 
 def init(folders=None, disable_plugins=False):
@@ -151,7 +150,7 @@ class Plugin(object):
     @property
     def tags(self):
         tags = getattr(self.cls, "PLUGIN_TAGS", [])
-        if isinstance(tags, string_types):
+        if isinstance(tags, str):
             tags = [tags]
         return tags
 
@@ -278,14 +277,14 @@ class PluginManager(object):
 
     @property
     def _modules(self):
-        return itervalues(self.__scanner.modules)
+        return self.__scanner.modules.values()
 
     @property
     def _plugins(self):
         """All registered plugins"""
 
         plugins = []
-        for module in itervalues(self.__modules):
+        for module in self.__modules.values():
             for plugin in module.plugins:
                 plugins.append(plugin)
         return plugins
@@ -369,7 +368,7 @@ class PluginManager(object):
         """module name: list of error message text lines"""
 
         errors = {}
-        for name, error in iteritems(self.__scanner.failures):
+        for name, error in self.__scanner.failures.items():
             exception = error.exception
             if isinstance(exception, PluginImportException):
                 if not exception.should_show():
@@ -383,7 +382,7 @@ class PluginManager(object):
     def quit(self):
         """Disable plugins and tell all handlers to clean up"""
 
-        for name in listkeys(self.__modules):
+        for name in list(self.__modules.keys()):
             self.__remove_module(name)
 
     def __remove_module(self, name):
@@ -459,7 +458,7 @@ class PluginConfigMixin(object):
     Mixin for storage and editing of plugin config in a standard way.
     """
 
-    CONFIG_SECTION = None
+    CONFIG_SECTION = ""
     """If defined, the section for storing config,
         otherwise, it will based on a munged `PLUGIN_ID`"""
 
@@ -469,9 +468,8 @@ class PluginConfigMixin(object):
 
     @classmethod
     def _get_config_option(cls, option):
-        try:
-            prefix = cls.CONFIG_SECTION
-        except AttributeError:
+        prefix = cls.CONFIG_SECTION
+        if not prefix:
             prefix = cls.PLUGIN_ID.lower().replace(" ", "_")
 
         return "%s_%s" % (prefix, option)
