@@ -33,7 +33,6 @@ from quodlibet.formats._audio import TAG_TO_SORT, AudioFile
 from quodlibet.qltk.x import SeparatorMenuItem
 from quodlibet.qltk.songlistcolumns import create_songlist_column
 from quodlibet.util import connect_destroy
-from quodlibet.compat import xrange, string_types, iteritems, listfilter
 
 
 DND_QL, DND_URI_LIST = range(2)
@@ -154,9 +153,9 @@ def get_sort_tag(tag):
         tag = "album"
 
     if "<" in tag:
-        for key, value in iteritems(replace_order):
+        for key, value in replace_order.items():
             tag = tag.replace("<%s>" % key, "<%s>" % value)
-        for key, value in iteritems(TAG_TO_SORT):
+        for key, value in TAG_TO_SORT.items():
             tag = tag.replace("<%s>" % key,
                                "<{1}|<{1}>|<{0}>>".format(key, value))
         tag = Pattern(tag).format
@@ -292,7 +291,7 @@ class SongListDnDMixin(object):
                 except ValueError:
                     return None
 
-            filenames = listfilter(None, map(to_filename, sel.get_uris()))
+            filenames = list(filter(None, map(to_filename, sel.get_uris())))
             move = False
         else:
             Gtk.drag_finish(ctx, False, False, etime)
@@ -305,7 +304,7 @@ class SongListDnDMixin(object):
             elif filename not in library:
                 to_add.append(library.librarian[filename])
         library.add(to_add)
-        songs = listfilter(None, map(library.get, filenames))
+        songs = list(filter(None, map(library.get, filenames)))
         if not songs:
             Gtk.drag_finish(ctx, bool(not filenames), False, etime)
             return
@@ -579,7 +578,7 @@ class SongList(AllTreeView, SongListDnDMixin, DragScroll,
     def __search_func(self, model, column, key, iter, *args):
         for column in self.get_columns():
             value = model.get_value(iter)(column.header_name)
-            if not isinstance(value, string_types):
+            if not isinstance(value, str):
                 continue
             elif key in value.lower() or key in value:
                 return False
@@ -907,7 +906,7 @@ class SongList(AllTreeView, SongListDnDMixin, DragScroll,
             return
         (start,), (end,) = vrange
         model = self.get_model()
-        for path in xrange(start, end + 1):
+        for path in range(start, end + 1):
             row = model[path]
             if row[0] in songs:
                 model.row_changed(row.path, row.iter)
@@ -916,7 +915,7 @@ class SongList(AllTreeView, SongListDnDMixin, DragScroll,
         window = qltk.get_top_parent(self)
         filter_ = window.browser.active_filter
         if callable(filter_):
-            self.add_songs(listfilter(filter_, songs))
+            self.add_songs(list(filter(filter_, songs)))
 
     def __song_removed(self, librarian, songs, player):
         # The player needs to be called first so it can ge the next song
@@ -1082,8 +1081,9 @@ class SongList(AllTreeView, SongListDnDMixin, DragScroll,
             ~#tracks albumartist""".split()
         dateinfo = """date originaldate recordingdate ~year ~originalyear
             ~#laststarted ~#lastplayed ~#added ~#mtime""".split()
-        fileinfo = """~format ~#bitrate ~#filesize ~filename ~basename ~dirname
-            ~uri ~codec ~encoding ~#channels""".split()
+        fileinfo = """~format ~#bitdepth ~#bitrate ~#filesize
+            ~filename ~basename ~dirname ~uri ~codec ~encoding ~#channels
+            ~#samplerate""".split()
         copyinfo = """copyright organization location isrc
             contact website""".split()
         all_headers = sum(
