@@ -3,10 +3,9 @@
 #           2011,2013 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
-
-from quodlibet.compat import text_type, iterbytes
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 
 def isascii(string):
@@ -54,9 +53,9 @@ def split_escape(string, sep, maxsplit=None, escape_char="\\"):
     assert len(escape_char) == 1
 
     if isinstance(string, bytes):
-        if isinstance(escape_char, text_type):
+        if isinstance(escape_char, str):
             escape_char = escape_char.encode("ascii")
-        iter_ = iterbytes
+        iter_ = lambda b: (bytes([v]) for v in b)
     else:
         iter_ = iter
 
@@ -99,9 +98,9 @@ def join_escape(values, sep, escape_char="\\"):
 
     # don't allow auto decoding of 'values'
     if values and isinstance(values[0], bytes):
-        if isinstance(escape_char, text_type):
+        if isinstance(escape_char, str):
             escape_char = escape_char.encode("ascii")
-        assert not isinstance(sep, text_type)
+        assert not isinstance(sep, str)
 
     escaped = []
     for value in values:
